kedro.io.AbstractVersionedDataSet — Kedro 0.17.6 documentation

# kedro.io.AbstractVersionedDataSet

class `kedro.io.` `AbstractVersionedDataSet`(filepath, version, exists_function=None, glob_function=None)

  `AbstractVersionedDataSet` is the base class for all versioned data set implementations. All data sets that implement versioning should extend this abstract class and implement the methods marked as abstract.

  Example:

      from pathlib import Path, PurePosixPath
      import pandas as pd
      from kedro.io import AbstractVersionedDataSet

      class MyOwnDataSet(AbstractVersionedDataSet):
          def __init__(self, filepath, version, param1, param2=True):
              super().__init__(PurePosixPath(filepath), version)
              self._param1 = param1
              self._param2 = param2

          def _load(self) -> pd.DataFrame:
              load_path = self._get_load_path()
              return pd.read_csv(load_path)

          def _save(self, df: pd.DataFrame) -> None:
              save_path = self._get_save_path()
              df.to_csv(str(save_path))

          def _exists(self) -> bool:
              path = self._get_load_path()
              return Path(path.as_posix()).exists()

          def _describe(self):
              return dict(version=self._version, param1=self._param1, param2=self._param2)

  Example catalog.yml specification:

      my_dataset:
          type: <path-to-my-own-dataset>.MyOwnDataSet
          filepath: data/01_raw/my_data.csv
          versioned: true
          param1: <param1-value> # param1 is a required argument
          # param2 will be True by default

  Methods

  `exists`() | Checks whether a data set’s output already exists by calling the provided _exists() method.
  `from_config`(name, config[, load_version, …]) | Create a data set instance using the configuration provided.
  `load`() | Loads data by delegation to the provided load method.
  `release`() | Release any cached data.
  `resolve_load_version`() | Compute the version the dataset should be loaded with.
  `resolve_save_version`() | Compute the version the dataset should be saved with.
  `save`(data) | Saves data by delegation to the provided save method.

  `__init__`(filepath, version, exists_function=None, glob_function=None)

    Creates a new instance of `AbstractVersionedDataSet`.

    Parameters

      - filepath (`PurePosixPath`) – Filepath in POSIX format to a file.

      - version (`Optional`[`Version`]) – If specified, should be an instance of `kedro.io.core.Version`. If its `load` attribute is None, the latest version will be loaded. If its `save` attribute is None, save version will be autogenerated.

      - exists_function (`Optional`[`Callable`[[`str`], `bool`]]) – Function that is used for determining whether a path exists in a filesystem.

      - glob_function (`Optional`[`Callable`[[`str`], `List`[`str`]]]) – Function that is used for finding all paths in a filesystem, which match a given pattern.

  `exists`()

    Checks whether a data set’s output already exists by calling the provided _exists() method.

    Return type

      `bool`

    Returns

      Flag indicating whether the output already exists.

    Raises

      DataSetError – when underlying exists method raises error.

  classmethod `from_config`(name, config, load_version=None, save_version=None)

    Create a data set instance using the configuration provided.

    Parameters

      - name (`str`) – Data set name.

      - config (`Dict`[`str`, `Any`]) – Data set config dictionary.

      - load_version (`Optional`[`str`]) – Version string to be used for `load` operation if the data set is versioned. Has no effect on the data set if versioning was not enabled.

      - save_version (`Optional`[`str`]) – Version string to be used for `save` operation if the data set is versioned. Has no effect on the data set if versioning was not enabled.

    Return type

      `AbstractDataSet`

    Returns

      An instance of an `AbstractDataSet` subclass.

    Raises

      DataSetError – When the function fails to create the data set from its config.

  `load`()

    Loads data by delegation to the provided load method.

    Return type

      `Any`

    Returns

      Data returned by the provided load method.

    Raises

      DataSetError – When underlying load method raises error.

  `release`()

    Release any cached data.

    Raises

      DataSetError – when underlying release method raises error.

    Return type

      `None`

  `resolve_load_version`()

    Compute the version the dataset should be loaded with.

    Return type

      `Optional`[`str`]

  `resolve_save_version`()

    Compute the version the dataset should be saved with.

    Return type

      `Optional`[`str`]

  `save`(data)

    Saves data by delegation to the provided save method.

    Parameters

      data (`Any`) – the value to be saved by provided save method.

    Raises

      - DataSetError – when underlying save method raises error.

      - FileNotFoundError – when save method got file instead of dir, on Windows.

      - NotADirectoryError – when save method got file instead of dir, on Unix.

    Return type

      `None`